pub enum Call {
Async,
Stream,
Generator,
Immediate,
}Expand description
How the function is called.
Async functions create a sub-context and immediately return futures.
Variants
Async
Function is async and returns a future that must be await:ed to make
progress.
Stream
Function produces a stream, also known as an async generator.
Generator
Function produces a generator.
Immediate
Functions are immediately called and control handed over.